%define major     1
%define libname   %mklibname %{name} %{major}
%define libnamepp %mklibname %{name}pp %{major}
%define develname %mklibname %{name} -d

Name:           mosquitto
Version:        1.6.15
Release:        %mkrel 1
Summary:        An Open Source MQTT v3.1/v3.1.1 Broker
Group:          System/Libraries
License:        BSD
URL:            http://mosquitto.org/
Source0:        http://mosquitto.org/files/source/%{name}-%{version}.tar.gz

BuildRequires:  cmake
BuildRequires:  tcp_wrappers-devel
BuildRequires:  uthash-devel >= 2.1.0
BuildRequires:  pkgconfig(libcares)
BuildRequires:  pkgconfig(libwebsockets)
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(systemd)
BuildRequires:  pkgconfig(uuid)

Requires(pre):  shadow-utils
Requires(post): systemd
Requires(preun): systemd
Requires(postun): systemd

%description
Mosquitto is an open source message broker that implements the MQ Telemetry
Transport protocol version 3.1 and 3.1.1 MQTT provides a lightweight method
of carrying out messaging using a publish/subscribe model. This makes it
suitable for "machine to machine" messaging such as with low power sensors
or mobile devices such as phones, embedded computers or micro-controllers
like the Arduino.

#------------------------------------------------

%package -n     %{libname}
Summary:        An Open Source MQTT v3.1/v3.1.1 Broker
Group:          System/Libraries

%description -n %{libname}
Mosquitto is an open source message broker that implements the MQ Telemetry
Transport protocol version 3.1 and 3.1.1 MQTT provides a lightweight method
of carrying out messaging using a publish/subscribe model. This makes it
suitable for "machine to machine" messaging such as with low power sensors
or mobile devices such as phones, embedded computers or micro-controllers
like the Arduino.

#------------------------------------------------

%package -n     %{libnamepp}
Summary:        An Open Source MQTT v3.1/v3.1.1 Broker
Group:          System/Libraries

%description -n %{libnamepp}
Mosquitto is an open source message broker that implements the MQ Telemetry
Transport protocol version 3.1 and 3.1.1 MQTT provides a lightweight method
of carrying out messaging using a publish/subscribe model. This makes it
suitable for "machine to machine" messaging such as with low power sensors
or mobile devices such as phones, embedded computers or micro-controllers
like the Arduino.

#------------------------------------------------

%package -n     %{develname}
Summary:        Development package for %{name}
Group:          Development/C++
Requires:       %{libname} = %{version}-%{release}
Requires:       %{libnamepp} = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}

%description -n %{develname}
Header files for development with %{name}.

#------------------------------------------------

%prep
%setup -q
%autopatch -p0

# Set the install prefix to /usr
sed -i "s|prefix?=/usr/local|prefix?=/usr|" config.mk
# Don't strip binaries on install: rpmbuild will take care of it
sed -i "s|(INSTALL) -s|(INSTALL)|g" lib/Makefile src/Makefile client/Makefile

%build
%cmake -DWITH_BUNDLED_DEPS=OFF -DWITH_SYSTEMD=ON -DWITH_WEBSOCKETS=ON
%make_build

%install
%make_install -C build

mkdir -p %{buildroot}%{_unitdir}
install -p -m 0644 service/systemd/%{name}.service.notify %{buildroot}%{_unitdir}/%{name}.service

%check
#make test

%pre
getent group %{name} >/dev/null || groupadd -r %{name}
getent passwd %{name} >/dev/null || \
    useradd -r -g %{name} -d %{_sysconfdir}/%{name} -s /sbin/nologin \
    -c "Mosquitto Broker" %{name}
exit 0

%post
%_post_service %{name}

%preun
%_preun_service %{name}

%postun
%_postun_service %{name}

%files
%doc ChangeLog.txt CONTRIBUTING.md readme.md
%license LICENSE.txt
%{_bindir}/*
%{_sbindir}/*
%dir %{_sysconfdir}/%{name}
%config(noreplace) %{_sysconfdir}/%{name}/%{name}.conf
%config %{_sysconfdir}/%{name}/*.example
%{_unitdir}/%{name}.service
%{_mandir}/man1/*.1.*
%{_mandir}/man5/*.5.*
%{_mandir}/man7/*.7.*
%{_mandir}/man8/*.8.*

%files -n %{libname}
%{_libdir}/lib%{name}.so.%{major}{,.*}

%files -n %{libnamepp}
%{_libdir}/lib%{name}pp.so.%{major}{,.*}

%files -n %{develname}
%{_includedir}/*.h
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc
%{_mandir}/man3/*.3.*


%changelog
* Sun Jun 27 2021 luigiwalser <luigiwalser> 1.6.15-1.mga7
+ Revision: 1734027
- 1.6.15
+ daviddavid <daviddavid>
- new version: 1.6.14, fixes new security issues (mga#29024)
- new version: 1.6.8, fixes multiple security issues (mga#25902)
- new version: 1.6.6, fixes CVE-2019-11779 (mga#25728)

* Thu Apr 18 2019 daviddavid <daviddavid> 1.6.0-1.mga7
+ Revision: 1393283
- new version: 1.6.0

* Sat Mar 02 2019 daviddavid <daviddavid> 1.5.8-1.mga7
+ Revision: 1371000
- new version: 1.5.8

* Sun Feb 17 2019 daviddavid <daviddavid> 1.5.7-1.mga7
+ Revision: 1367860
- new version: 1.5.7

* Sat Feb 09 2019 daviddavid <daviddavid> 1.5.6-1.mga7
+ Revision: 1364447
- new version: 1.5.6

* Sat Dec 15 2018 daviddavid <daviddavid> 1.5.5-1.mga7
+ Revision: 1341327
- new version: 1.5.5

* Sat Nov 24 2018 daviddavid <daviddavid> 1.5.4-2.mga7
+ Revision: 1333910
- rebuild for new libwebsockets 3.1.0

* Tue Nov 13 2018 daviddavid <daviddavid> 1.5.4-1.mga7
+ Revision: 1329705
- new version: 1.5.4

* Thu Oct 11 2018 daviddavid <daviddavid> 1.5.3-1.mga7
+ Revision: 1319505
- new version: 1.5.3

* Fri Sep 21 2018 daviddavid <daviddavid> 1.5.2-1.mga7
+ Revision: 1294636
- new version: 1.5.2

* Tue Aug 21 2018 daviddavid <daviddavid> 1.5.1-1.mga7
+ Revision: 1253205
- new version: 1.5.1

* Sun May 27 2018 daviddavid <daviddavid> 1.5-2.mga7
+ Revision: 1232367
- use upstream systemd service and enable systemd notification support
- add network-online.target and documentation to unitfile

* Mon May 21 2018 daviddavid <daviddavid> 1.5-1.mga7
+ Revision: 1230998
- initial package mosquitto

